(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22805,        849]*)
(*NotebookOutlinePosition[     24431,        901]*)
(*  CellTagsIndexPosition[     24358,        895]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(AVF\ COMMANDS\),
        FontFamily->"Helvetica",
        FontSize->14,
        FontVariations->{"Underline"->True}]}]], "Input"],

Cell[TextData[{
  "\n(*The command syntax of the basic AVF operations is illustrated with \
very brief descriptions. The notebook should be run with Evaluate \
Initialization and then scrolled through for viewing. It's best to start with \
a fresh Kernel to avoid possible problems with prior assignments. The \
AVF_Demo.nb notebook covers the same ground in more detail, as well as some \
important additional topics, and the text file ",
  ButtonBox["AVF_Introduction.nb",
    ButtonData:>{"   AVF_Introduction.nb", None},
    ButtonStyle->"Hyperlink"],
  " explains the overall design of AVF. AVFstartup.nb shows a sample of \
editable commands to set up new AVF calculations.*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n (*GETTING\ AVF*) \)\)], "Input"],

Cell[BoxData[
    \(\(<< AVF.m;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*ESTABLISHING\ THE\ QUATERNION\ ALGEBRA, \ H*) \)\)], "Input"],

Cell[TextData[{
  "(*Introduce a list of four \"elements\", where the initial element ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_0\)]],
  " is the identity.*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeelements[{\[Sigma]\_0, \[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}]\)], \
"Input",
  InitializationCell->True],

Cell["(*The multiplication table defining H is entered,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(H = {{\[Sigma]\_0, \[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}, \
{\[Sigma]\_1, \(-\[Sigma]\_0\), \[Sigma]\_3, \(-\[Sigma]\_2\)}, {\[Sigma]\_2, \
\(-\[Sigma]\_3\), \(-\[Sigma]\_0\), \[Sigma]\_1}, {\[Sigma]\_3, \[Sigma]\_2, \
\(-\[Sigma]\_1\), \(-\[Sigma]\_0\)}};\)\)], "Input",
  InitializationCell->True],

Cell["(*and this becomes the established \"algebra\" by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makealgebra[H]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(algebra\)], "Input",
  InitializationCell->True],

Cell["\<\
(*With no argument, mtx[] outputs its default argument \"algebra\" \
as a matrix*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["(*Input a general quaternion,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q = Sum[\(x\_i\) \[Sigma]\_i, {i, 0, 3}]\)], "Input",
  InitializationCell->True],

Cell["(*and construct its conjugate,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q\&_ = \(-q\) /. x\_0 -> \(-x\_0\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*MULTIPLICATION*) \)\)], "Input"],

Cell["\<\
(*AVF multiplication uses , ** , the NonCommutativeMultiply infix \
operator,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q ** q\&_\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The identity element generally is suppressed in output from AVF \
operations. An independent quaternion,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Q = q /. x -> \[Omega]\)], "Input",
  InitializationCell->True],

Cell["(*with the non-commutative quaternion product,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(qQ = q ** Q\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(q ** Q - Q ** q\)], "Input",
  InitializationCell->True],

Cell["(*Any number of AVFs can be multiplied together,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q ** Q ** q\&_\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and if the \"algebra\" table specifies a non-associative algebra, \
the order of performing triple products may be important. But for H, it's \
not,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((q ** Q)\) ** q\&_ - q ** \((Q ** q\&_)\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*All the commands used herein can be applied to non-associative \
cases, such as octonions and Lie algebras, with due regard for the ordering \
of triple products. Examples are given in Miscellany_Demo.nb.*)\
\>", "Input",\

  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n (*FORMAT\ COMMANDS*) \)\)], "Input"],

Cell["\<\
(*The non-zero coefficients of the algebra elements in an AVF, such \
as qQ , are returned in a list by*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(coeffs[qQ]\)], "Input",
  InitializationCell->True],

Cell["(*and the AVF expression is output in collected form by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[qQ]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*This is the only AVF command that always outputs the identity \
element explicitly. The result contains the usual scalar and vector products \
for 3-vectors,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(% /. {x\_0 -> 0, \[Omega]\_0 -> 0}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*DIFFERENTIATION*) \)\)], "Input"],

Cell["\<\
(*Exterior differentiation is accomplished with the operator d[] , \
but since no \"scalars\" or \"forms\" lists have been established yet, all \
quantities are treated as constants,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[qQ]\)], "Input",
  InitializationCell->True],

Cell["(*The coefficients in q*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q\)], "Input",
  InitializationCell->True],

Cell["(* can be made into independent scalar fields by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[coeffs[q]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the \"makescalars\" command also generates their 1-form \
derivative symbols, \"dscalars\",*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The \"algebra\" elements themselves are always constants, but q \
has become a quaternion field,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[q]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[q ** q\&_]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The coefficients in Q can be established as non-exact basis \
1-forms by,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeforms[coeffs[Q]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*where the independent basis 1-forms will include \"dscalars\" \
automatically, and the non-exact forms have derivative symbols in \
\"dforms\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dforms\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The quantity Q is now a quaternion-valued 1-form field with the \
2-form derivative,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[Q]\)], "Input",
  InitializationCell->True],

Cell["(*and the AVF self-product,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(QQ = Q ** Q\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The derivative of the previously defined variable qQ now gives \
the quaternion 2-form,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[d[qQ]]\)], "Input",
  InitializationCell->True],

Cell["\<\

(*In field theories, the AVF 2-form field, F , is important,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(F = collect[d[Q] + QQ/2]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*where the coefficients have the structure of Maurer-Cartan forms \
for the quaternion algebra,*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(coeffs[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the quaternion-valued \"curvature\" 2-form satisfies the \
3-form Bianchi identity,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[F] + Q ** \((F/2)\) - \((F/2)\) ** Q\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Similar AVF structures can be defined for other associative \
algebras (such as the geometric Clifford algebras, which include H), and for \
non-associative algebras (e.g., Lie or supersymmetric graded Lie algebras).\
\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\

(*The derivative operator can also be applied to a list of AVFs.*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[{q ** q\&_, QQ}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*ORDINARY\ DIFFERENTIAL\ FORMS*) \)\)], "Input"],

Cell["\<\
(*Any ordinary differential form expression can be input simply by \
omitting the algebra elements. Absent elements default to the identity \
element of the algebra, which only appears with \"collect\"; e.g.,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(f = \((\(x\_1\) \[Omega]\_2\[Wedge]dx\_2 + \(x\_0\) 
              d\[Omega]\_3)\) ** \((\[Omega]\_3 + \[Omega]\_2)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[f]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(df = d[f]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Since ordinary differential forms are treated as a trivial \
\"algebra\", all AVF commands will work equally well in either case.*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n (*FACTOR\ AND\ EXPAND*) \)\)], "Input"],

Cell["\<\
(*Any member of \"forms\" or \"dforms\" can be factored out to the \
left of an AVF by the following command, where all terms containing the basis \
form will be factored.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(fac = factor[d\[Omega]\_3, df]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and so the original, df , can be recovered by using \"expand\" on \
the next expression,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((df /. d\[Omega]\_3 -> 0)\) + d\[Omega]\_3\[Wedge]fac\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The AVF command \"expand\" is analogous to Mathematica's \"Expand\
\", except that it also expands wedge products, and so allows arbitrary \
replacements within them at all levels of an AVF expression. Note that the \
wedge symbol has the usual meaning of exterior product between basis forms, \
but is neither recognized nor used as an operator.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Q\[Wedge]QQ\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(% /. \[Omega]\_2 -> \((dx\_1 + dx\_3)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(expand[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*VECTOR\ CONTRACTION*) \)\)], "Input"],

Cell["\<\
(*A vector in AVF is a list of scalar variables with the same \
length as the \"forms\" list. The list represents the components of the \
vector in the dual basis to \"forms\". The components will be constants, \
unless they are chosen from the \"scalars\" list, or are input as specified \
or unspecified functions of \"scalars\". Define two independent vectors, V1 \
and V2,  with symbols adapted to the \"forms\" list:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(V1 = {W1\_0, W1\_1, W1\_2, W1\_3, X1\_0, X1\_1, X1\_2, X1\_3}\), "\n", 
    \(V2 = {W2\_0, W2\_1, W2\_2, W2\_3, X2\_0, X2\_1, X2\_2, 
        X2\_3}\)}], "Input",
  InitializationCell->True],

Cell["\<\
(*Vector contractions are given by the SmallCircle infix operator, \
typed as {esc s c esc} ; i.e., vector \[SmallCircle] AVF . Contraction can \
also be applied to a list of AVFs, and multiple contractions can be performed \
together. On the list of basis 1-forms, it simply returns the vector \
itself;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V1\[SmallCircle]forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(V1\[SmallCircle]{QQ, d[q]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(V1\[SmallCircle]V2\[SmallCircle]QQ\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[%]\)], "Input",
  InitializationCell->True],

Cell["(*These vectors are constant,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[V1]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*but the components can be input as functions of \
\"scalars\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V1 = {W1\_0[x\_0], W1\_1[x\_1], W1\_2[x\_2], W1\_3[x\_3], X1\_0, X1\_1, 
        X1\_2, X1\_3}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[V1]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(V1\[SmallCircle]QQ\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[d[%]]\)], "Input",
  InitializationCell->True],

Cell["\<\
 (*or even be entered into \"scalars\" themselves to make them \
independent fields with their own derivatives,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[Join[scalars, V2]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(V2\[SmallCircle]QQ\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[d[%]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Contraction on this last expression would require a longer vector \
to encompass the additional independent basis 1-forms created by extending \
the \"scalars\" list. It would also require defining contractions on the \
members of \"dforms\". These topics are discussed in AVF_Demo.nb and \
LieDerivative_Demo.nb .*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\

(*The \"makescalars\" command just above illustrates a general feature of \
AVF; i.e., that the fundamental lists,  \"scalars\", \"forms\", \"elements\", \
and \"algebra\", can be changed at any time by executing the respective \
\"make\" command. For instance, the vector components can be deleted from \
\"scalars\" by,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[Complement[scalars, V2]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell["(*This doesn't delete them from Kernel memory,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V2\)], "Input",
  InitializationCell->True],

Cell["(*but they do revert to being constant parameters in AVF.*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[V2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*MATRIX\ REPRESENTATIONS\ AND\ OPERATIONS*) \)\)], "Input"],

Cell["\<\
(*Sometimes it is useful to have a matrix representation of the \
algebra elements, even though the program never requires it. For example, the \
quaternion elements can be represented by Pauli-type matrices, which have the \
same multiplication table as H,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["(*for instance,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalSigma]\_0 = {{1, 0}, {0, 1}}; \[CapitalSigma]\_1 = {{0, 
          I}, {I, 0}}; \[CapitalSigma]\_2 = {{0, \(-1\)}, {1, 
          0}}; \[CapitalSigma]\_3 = {{I, 0}, {0, \(-I\)}};\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\((\[CapitalSigma]\_1)\) . \[CapitalSigma]\_1 == \
\(-\[CapitalSigma]\_0\)\), "\n", 
    \(\((\[CapitalSigma]\_1)\) . \[CapitalSigma]\_2 == \
\[CapitalSigma]\_3\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*and since the indices of these matrices agree with the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  ", any quaternion expression or list can be converted to a matrix by \
replacement of the symbol kernel; i.e.,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(elements /. \[Sigma] -> \[CapitalSigma]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(q\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mq = q /. \[Sigma] -> \[CapitalSigma]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(QQ\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mQQ = QQ /. \[Sigma] -> \[CapitalSigma]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*When the AVF includes a suppressed identity element, it is \
necessary to make it explicit by using \"collect\" before conversion; e.g.,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q ** q\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[q ** q] /. \[Sigma] -> \[CapitalSigma]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Since the matrix mq has only scalar components, Mathematica's \
matrix product gives the same result,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Expand[mq . mq]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*AVF\ MATRICES*) \)\)], "Input"],

Cell["\<\
(*The AVF program includes an infix operator, denoted CircleTimes \
and typed by {esc c * esc}, that can be used when the matrix elements are \
complete AVFs, such as quaternion-valued p-forms. For instance, the above \
matrix mQQ can be calculated using the matrix form of Q having 1-form \
elements,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mQ = Q /. \[Sigma] -> \[CapitalSigma]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[mQ\[CircleTimes]mQ]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Using Mathematica's \"BlockMatrix[]\" command, the matrices mq \
and mQ can be combined to give a graded matrix, GM, with diagonal blocks of \
even grade (0-forms) and off-diagonal blocks of odd grade (1-forms). Such \
matrices generate supergroups and their commutators generate the associated \
Lie superalgebras.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["<< LinearAlgebra`MatrixManipulation`;", "Input",
  InitializationCell->True,
  CellTags->"S5.52.1"],

Cell["\<\
(*For brevity, the identity elements are deleted in this example,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(GM = 
      BlockMatrix[{{mq, mQ}, {mQ, \(-mq\)}}] /. {x\_0 -> 0, \[Omega]\_0 -> 
            0}; mtx[GM]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The product is a graded matrix of the same general type; i.e., \
diagonal blocks of even grades in the Grassmann algebra and off-diagonal \
blocks of odd grade: *)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[GM\[CircleTimes]GM]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A graded matrix equivalent to GM can be expressed more concisely \
with a 2\[Times]2 matrix of the quaternion-valued AVFs,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(QM = {{q, Q}, {Q, \(-q\)}} /. {x\_0 -> 0, \[Omega]\_0 -> 0}; 
    mtx[QM]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[BlockMatrix[QM /. \[Sigma] -> \[CapitalSigma]]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and it can be multiplied directly with the CircleTimes operator, \
giving essentially the same result for the matrix product, but in a \
representation-independent and slightly more compact form,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(QM2 = collect[QM\[CircleTimes]QM]; mtx[QM2]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Note that as a matrix QM is symmetric, but its expanded form GM \
is unsymmetric (anti-Hermitian), so matrix operations involving transposes \
and conjugates must be defined and handled differently.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\

(*Since d[] maps recursively onto AVF lists, it also extends to AVF \
matrices,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[d[QM2]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell["(*and the same is true for contractions,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[V2\[SmallCircle]QM2]\)], "Input",
  InitializationCell->True],

Cell["(*For a quaternion-valued, even-odd, column vector,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(QV = {{q\&_}, {Q}} /. {x\_0 -> 0, \[Omega]\_0 -> 0}\)], "Input",
  InitializationCell->True],

Cell["\<\
(*the QM \[CircleTimes] QV product returns an even-odd column \
vector*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(QM\[CircleTimes]QV\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and finally, a single, quaternion-valued, even-grade, p-form,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[Transpose[QV]\[CircleTimes]%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(timer[]\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
WindowSize->{663, 506},
WindowMargins->{{11, Automatic}, {Automatic, 2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True},
Magnification->1,
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?mooh<<H`Ui0fL5:0?l0080004/0B`000000]P2:002
0000I00000400`<300000BL?00400@gZb80000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.52.1"->{
    Cell[19766, 728, 105, 2, 27, "Input",
      InitializationCell->True,
      CellTags->"S5.52.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.52.1", 24230, 887}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 179, 5, 43, "Input"],
Cell[1936, 58, 718, 13, 124, "Input"],
Cell[2657, 73, 57, 1, 43, "Input"],
Cell[2717, 76, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[2794, 80, 88, 1, 43, "Input"],
Cell[2885, 83, 206, 6, 28, "Input"],
Cell[3094, 91, 129, 3, 27, "Input",
  InitializationCell->True],
Cell[3226, 96, 91, 1, 28, "Input"],
Cell[3320, 99, 322, 5, 27, "Input",
  InitializationCell->True],
Cell[3645, 106, 92, 1, 28, "Input"],
Cell[3740, 109, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[3818, 113, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[3889, 117, 130, 4, 28, "Input"],
Cell[4022, 123, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[4091, 127, 71, 1, 28, "Input"],
Cell[4165, 130, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[4269, 134, 72, 1, 28, "Input"],
Cell[4344, 137, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[4442, 141, 59, 1, 43, "Input"],
Cell[4504, 144, 127, 4, 28, "Input"],
Cell[4634, 150, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[4707, 154, 156, 4, 28, "Input"],
Cell[4866, 160, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[4952, 164, 88, 1, 28, "Input"],
Cell[5043, 167, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[5118, 171, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[5197, 175, 90, 1, 28, "Input"],
Cell[5290, 178, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[5368, 182, 200, 5, 44, "Input"],
Cell[5571, 189, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[5678, 193, 258, 6, 44, "Input"],
Cell[5939, 201, 61, 1, 43, "Input"],
Cell[6003, 204, 153, 4, 28, "Input"],
Cell[6159, 210, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[6233, 214, 98, 1, 28, "Input"],
Cell[6334, 217, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[6409, 221, 209, 5, 44, "Input"],
Cell[6621, 228, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[6719, 232, 60, 1, 43, "Input"],
Cell[6782, 235, 232, 5, 44, "Input"],
Cell[7017, 242, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[7086, 246, 65, 1, 28, "Input"],
Cell[7154, 249, 62, 2, 27, "Input",
  InitializationCell->True],
Cell[7219, 253, 91, 1, 28, "Input"],
Cell[7313, 256, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[7399, 260, 148, 4, 28, "Input"],
Cell[7550, 266, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[7622, 270, 148, 4, 28, "Input"],
Cell[7773, 276, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[7841, 280, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[7917, 284, 125, 4, 28, "Input"],
Cell[8045, 290, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[8129, 294, 195, 5, 44, "Input"],
Cell[8327, 301, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[8397, 305, 136, 4, 28, "Input"],
Cell[8536, 311, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[8604, 315, 69, 1, 28, "Input"],
Cell[8676, 318, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[8751, 322, 139, 4, 28, "Input"],
Cell[8893, 328, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[8971, 332, 111, 4, 44, "Input"],
Cell[9085, 338, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[9173, 342, 147, 4, 28, "Input"],
Cell[9323, 348, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[9396, 352, 139, 4, 28, "Input"],
Cell[9538, 358, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[9640, 362, 268, 6, 44, "Input"],
Cell[9911, 370, 117, 5, 44, "Input"],
Cell[10031, 377, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[10113, 381, 74, 1, 43, "Input"],
Cell[10190, 384, 260, 6, 44, "Input"],
Cell[10453, 392, 178, 3, 27, "Input",
  InitializationCell->True],
Cell[10634, 397, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[10708, 401, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[10781, 405, 183, 5, 44, "Input"],
Cell[10967, 412, 64, 1, 43, "Input"],
Cell[11034, 415, 221, 5, 44, "Input"],
Cell[11258, 422, 91, 2, 27, "Input",
  InitializationCell->True],
Cell[11352, 426, 140, 4, 28, "Input"],
Cell[11495, 432, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[11614, 436, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[11687, 440, 398, 7, 76, "Input"],
Cell[12088, 449, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[12163, 453, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[12266, 457, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[12339, 461, 64, 1, 43, "Input"],
Cell[12406, 464, 471, 8, 76, "Input"],
Cell[12880, 474, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[12949, 478, 211, 4, 43, "Input",
  InitializationCell->True],
Cell[13163, 484, 354, 7, 60, "Input"],
Cell[13520, 493, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[13605, 497, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[13695, 501, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[13793, 505, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[13867, 509, 71, 1, 28, "Input"],
Cell[13941, 512, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[14010, 516, 114, 4, 28, "Input"],
Cell[14127, 522, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[14285, 527, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[14354, 531, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[14436, 535, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[14513, 539, 161, 4, 28, "Input"],
Cell[14677, 545, 91, 2, 27, "Input",
  InitializationCell->True],
Cell[14771, 549, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[14840, 553, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[14922, 557, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[14999, 561, 366, 7, 60, "Input"],
Cell[15368, 570, 372, 8, 76, "Input"],
Cell[15743, 580, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[15843, 584, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[15912, 588, 88, 1, 28, "Input"],
Cell[16003, 591, 63, 2, 27, "Input",
  InitializationCell->True],
Cell[16069, 595, 99, 1, 28, "Input"],
Cell[16171, 598, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[16240, 602, 85, 1, 43, "Input"],
Cell[16328, 605, 307, 6, 60, "Input"],
Cell[16638, 613, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[16707, 617, 57, 1, 28, "Input"],
Cell[16767, 620, 248, 4, 43, "Input",
  InitializationCell->True],
Cell[17018, 626, 223, 5, 43, "Input",
  InitializationCell->True],
Cell[17244, 633, 288, 7, 44, "Input"],
Cell[17535, 642, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[17607, 646, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[17710, 650, 62, 2, 27, "Input",
  InitializationCell->True],
Cell[17775, 654, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[17876, 658, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[17946, 662, 63, 2, 27, "Input",
  InitializationCell->True],
Cell[18012, 666, 100, 2, 27, "Input",
  InitializationCell->True],
Cell[18115, 670, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[18185, 674, 190, 5, 44, "Input"],
Cell[18378, 681, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[18448, 685, 107, 2, 27, "Input",
  InitializationCell->True],
Cell[18558, 689, 153, 4, 28, "Input"],
Cell[18714, 695, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[18793, 699, 58, 1, 43, "Input"],
Cell[18854, 702, 351, 7, 60, "Input"],
Cell[19208, 711, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[19309, 715, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[19396, 719, 367, 7, 60, "Input"],
Cell[19766, 728, 105, 2, 27, "Input",
  InitializationCell->True,
  CellTags->"S5.52.1"],
Cell[19874, 732, 117, 4, 28, "Input"],
Cell[19994, 738, 166, 4, 43, "Input",
  InitializationCell->True],
Cell[20163, 744, 213, 5, 44, "Input"],
Cell[20379, 751, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[20466, 755, 174, 4, 44, "Input"],
Cell[20643, 761, 134, 3, 27, "Input",
  InitializationCell->True],
Cell[20780, 766, 112, 2, 27, "Input",
  InitializationCell->True],
Cell[20895, 770, 247, 5, 44, "Input"],
Cell[21145, 777, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[21252, 781, 250, 5, 44, "Input"],
Cell[21505, 788, 130, 5, 44, "Input"],
Cell[21638, 795, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[21717, 799, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[21785, 803, 82, 1, 28, "Input"],
Cell[21870, 806, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[21962, 810, 93, 1, 28, "Input"],
Cell[22058, 813, 112, 2, 27, "Input",
  InitializationCell->True],
Cell[22173, 817, 120, 4, 28, "Input"],
Cell[22296, 823, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[22378, 827, 115, 4, 28, "Input"],
Cell[22496, 833, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[22597, 837, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[22665, 841, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[22733, 845, 68, 2, 27, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

