(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29818,       1012]*)
(*NotebookOutlinePosition[     31402,       1062]*)
(*  CellTagsIndexPosition[     31326,       1056]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"                                                  ", 
          StyleBox[" ",
            FontFamily->"Palatino"]}]], "\n", 
      StyleBox["  ",
        FontFamily->"Palatino"], 
      StyleBox["MISCELLANY",
        FontFamily->"Helvetica",
        FontSize->14,
        FontVariations->{"Underline"->True}]}]], "Input",
  TextAlignment->Left],

Cell[TextData[{
  "(*This Notebook contains a miscellaneous collection of AVF calculations. \
Most of the operations used are introduced and explained in other Demos. The \
first example treats the Dirac equation with quaternion matrices. The rest \
involve a variety of non-associative algebras.  Some of these exercises were \
suggested by the fine review book on non-associative algebras by Susumu Okubo \
(",
  ButtonBox["Ref. at end",
    ButtonData:>"reference",
    ButtonStyle->"Hyperlink"],
  ").  Any existing Kernel should be Quit before starting with Evaluate \
Initialization. Running time:  < 1 min.*)  "
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(<< AVF.m;\)\)], "Input",
  InitializationCell->True],

Cell["(*Setting up the quaternion algebra, H *)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeelements[{\[Sigma]\_0, \[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}]\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(H = {{\[Sigma]\_0, \[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}, \
{\[Sigma]\_1, \(-\[Sigma]\_0\), \[Sigma]\_3, \(-\[Sigma]\_2\)}, {\[Sigma]\_2, \
\(-\[Sigma]\_3\), \(-\[Sigma]\_0\), \[Sigma]\_1}, {\[Sigma]\_3, \[Sigma]\_2, \
\(-\[Sigma]\_1\), \(-\[Sigma]\_0\)}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makealgebra[H]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["(*with three independent quaternions,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q1 = Sum[\(X\_i\) \[Sigma]\_i, {i, 0, 3}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(q2 = q1 /. X -> Y\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(q3 = q1 /. X -> Z\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*THE\ DIRAC\ EQUATION\ USING\ QUATERNIONS*) \)\)], "Input"],

Cell["\<\
(*A familiar 2\[Times]2 representation of Dirac matrices can be \
expressed by the quaternion elements, \[Sigma] ;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalGamma]\_0 = {{0, \ \[Sigma]\_2}, {\ \[Sigma]\_2, 
          0}}; \[CapitalGamma]\_1 = 
      I {{0, \[Sigma]\_1}, {\[Sigma]\_1, 
            0}}; \[CapitalGamma]\_2 = {{\[Sigma]\_0, 
          0}, {0, \(-\[Sigma]\_0\)}}; \[CapitalGamma]\_3 = 
      I {{0, \[Sigma]\_3}, {\[Sigma]\_3, 0}};\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The operator CircleTimes multiplies matrices of AVF expressions, \
and for the squares of the \[CapitalGamma]'s gives the Lorentz signature, \
{-1,1,1,1}; i.e.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(-\[CapitalGamma]\_0\)\[CircleTimes]\[CapitalGamma]\_0 == \
\[CapitalGamma]\_1\[CircleTimes]\[CapitalGamma]\_1 == \[CapitalGamma]\_2\
\[CircleTimes]\[CapitalGamma]\_2 == \[CapitalGamma]\_3\[CircleTimes]\
\[CapitalGamma]\_3 == {{1, 0}, {0, 1}}\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*where, as usual, the identity element ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(\(0\)\(\ \)\)\)]],
  "is suppressed in AVF results, but can be recovered using \"collect\". They \
all anti-commute among themselves, and also with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_5\)]],
  ",*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalGamma]\_5 = \[CapitalGamma]\_0\[CircleTimes]\[CapitalGamma]\_1\
\[CircleTimes]\[CapitalGamma]\_2\[CircleTimes]\[CapitalGamma]\_3\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[CapitalGamma]\_5\[CircleTimes]\[CapitalGamma]\_5\)], "Input",
  InitializationCell->True],

Cell["\<\

(*Make the coefficients of q1 and q2 into scalar variables,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[Join[coeffs[q1], coeffs[q2]]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and define a quaternion-valued 2-vector, qV , to represent the \
Dirac field,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(qV = {{q1}, {q2}}; mtx[qV]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Introducing a new set of \"scalars\" called \"coords\" will \
automatically construct partial derivative expansions for the exterior \
derivatives of q1 and q2, and these expressions are incorporated in \
\"drules\" by the \"makecoords\" command, as is described more fully in \
LieDerivative_Demo.nb.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{t, x, y, z}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(scalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell["(*Thus,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[q1]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[applydrules[%]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*or equivalently, using the compound operator, da[arg] = \
applydrules[d[arg]],*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[da[q1]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A particular partial derivative of an AVF expression, or list, is \
given either by the coordinate name appearing as a subscript on D,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(D\_x[qV]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*or by the position of the coordinate variable in the \"coords\" \
list,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(D\_1[qV]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The Dirac equation can then be written as the quaternion-valued \
2-vector equation,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dirac = 
      collect[\[Sum]\+\(i = 0\)\%3 
              I\ \[CapitalGamma]\_i\[CircleTimes]D\_\(i + 1\)[qV] + 
          I\ m\ \[CapitalGamma]\_5\[CircleTimes]qV]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and applying the same operator a second time returns the \
Klein-Gordon equation for each quaternion component,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(KG = 
      collect[\[Sum]\+\(i = 0\)\%3 
              I\ \[CapitalGamma]\_i\[CircleTimes]D\_\(i + 1\)[dirac] + 
          I\ m\ \[CapitalGamma]\_5\[CircleTimes]\ dirac]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*GENERAL\ ALGEBRAS*) \)\)], "Input"],

Cell[TextData[{
  "(*The \"algebra\" table may contain unspecified parameters in the \
products. For example, the procedure \"generic[]\" constructs a completely \
general algebra for \"elements\" using structure parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`sy\_\(i, j, k\)\)]],
  " which are symmetric in the {j,k} indices and ",
  Cell[BoxData[
      \(TraditionalForm\`sk\_\(i, j, k\)\)]],
  "which are skew-symmetric in {j,k}. The indices {i,j,k} start at (0,1,1) \
with 0 denoting the \"identity\" element. Only the independent parameters \
with (j \[LessEqual] k) are defined. The algebra can be established by:*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makealgebra[generic[]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and so with the present \"elements\" constructs the lists \
\"symm\" and \"skew\" and the generic algebra*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "                              (*                ",
  Cell[BoxData[
      FormBox[
        RowBox[{"      ", 
          RowBox[{
            FormBox[\(\[Sigma]\_j\),
              "TraditionalForm"], \(\[Sigma]\_k\)}]}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\+i\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"  ", 
            FormBox[
              RowBox[{
                FormBox[\((\ sy\_\(i, j, k\)\),
                  "TraditionalForm"], "+", \(sk\_\(i, j, k\)\)}],
              "TraditionalForm"], ")"}], \(\[Sigma]\_i\)}], 
        TraditionalForm]]],
  "                     *)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(symm\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(skew\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Either \"Expand\" or \"collect\" can be used to obtain \
appropriate cancellations here;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(commutator = 
      Expand[\[Sigma]\_1 ** \[Sigma]\_2 - \[Sigma]\_2 ** \[Sigma]\_1]\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(anticommutator = 
      Expand[\[Sigma]\_1 ** \[Sigma]\_2 + \[Sigma]\_2 ** \[Sigma]\_1]\)], \
"Input",
  InitializationCell->True],

Cell["(*The arbitrary algebra is non-associative,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[\((\[Sigma]\_1 ** \[Sigma]\_2)\) ** \[Sigma]\_1 - \[Sigma]\_1 ** \
\((\[Sigma]\_2 ** \[Sigma]\_1)\)]\)], "Input",
  InitializationCell->True],

Cell["(*The generic[] product of q1 and q2,*)", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[q1 ** q2]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*One application of generic[] is simply to solve for the structure \
constants of a given algebra table. The subroutine, structure[], gives the \
solution in \"constants\".\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(structure[arg_] := \((makealgebra[generic[]]; 
        diff = collect[arg - algebra]; 
        eqns = setzero[Flatten[Map[coeffs, Flatten[diff]]]]; 
        constants = Flatten[Solve[eqns, Join[skew, symm]]];)\)\)], "Input",
  InitializationCell->True],

Cell["(*For H,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(structure[H]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(constants\)], "Input",
  InitializationCell->True],

Cell["(*The quaternion product can be recovered by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[q1 ** q2 /. constants]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and H is restored as the active \"algebra\" by replacing the \
constants in the current generic algebra,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makealgebra[algebra /. constants]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The generic algebra may not be of much use beyond demonstrating \
generality; i.e., one can use p-form
AVFs defined over: Clifford, Lie, and Jordan algebras, other \
non-associative(e.g., octonion) algebras, gauge group algebras, and \
superalgebras.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n (*DERIVED\ ALGEBRAS*) \)\)], "Input"],

Cell[TextData[{
  "(*The non-associative derived algebras, ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\^-\)\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\^+\)\)]],
  ", for AVFs may also be defined: (",
  ButtonBox["see Okubo, p.19",
    ButtonData:>"reference",
    ButtonStyle->"Hyperlink"],
  "). In Mathematica, they can be easily input using the following two infix \
operators:*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The commutator function for AVFs, typed by (esc c - esc);*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(CircleMinus[arg1_, arg2_] := 
      arg1 ** \((arg2/2)\) - \((arg2/2)\) ** arg1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[q1]\[CircleMinus]d[q2]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The anti-commutator function for AVFs, typed by (esc c + \
esc);*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(CirclePlus[arg1_, arg2_] := 
      arg1 ** \((arg2/2)\) + \((arg2/2)\) ** arg1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[q1]\[CirclePlus]d[q2]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*For an associative underlying algebra, such as H , operator \
\[CircleMinus] defines a Lie-algebra, ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\^-\)\)]],
  ", over AVFs with the Jacobi identity,*)"
}], "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(d[q1]\[CircleMinus]\((d[q2]\[CircleMinus]q3)\) + 
      d[q2]\[CircleMinus]\((q3\[CircleMinus]d[q1])\) + 
      q3\[CircleMinus]\((d[q1]\[CircleMinus]d[q2])\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*and the \[CirclePlus] operator gives a special Jordan algebra, ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\^+\)\)]],
  ", satisfying the Jordan identity,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((\((d[q1] ** d[q1])\)\[CirclePlus]q3)\)\[CirclePlus]d[
          q1] - \((d[q1] ** 
            d[q1])\)\[CirclePlus]\((q3\[CirclePlus]d[q1])\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The following joint identity also holds in the underlying \
associative case, as well as in some special non-associative cases,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[q1]\[CircleMinus]\((d[q2]\[CirclePlus]q3)\) - \((d[q1]\[CircleMinus]d[
              q2])\)\[CirclePlus]q3 - 
      d[q2]\[CirclePlus]\((d[q1]\[CircleMinus]q3)\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and that expression implies the cyclic super-Jacobi identity,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[q1]\[CircleMinus]\((d[q2]\[CirclePlus]q3)\) + 
      d[q2]\[CircleMinus]\((q3\[CirclePlus]d[q1])\) + 
      q3\[CircleMinus]\((d[q1]\[CirclePlus]d[q2])\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*These operations are not supplied in AVF as reserved functions, \
but can be introduced as above.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\n (*GENERATING\ A\ LIE\ ALGEBRA*) \)\)], "Input",
  PageBreakAbove->True],

Cell["\<\
(*We start with the associative Clifford algebra, signature = \
{-1,1,1,1}, but with the algebra table truncated to grade(2) \
products;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeclifford[{\(-1\), 1, 1, 1}, 2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The full \"elements\" list must be retained, since they all \
appear in \"algebra\", though products of grades higher than grade(2) cannot \
be performed.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The table of commutator products for the truncated \"elements\" \
is given by,*)\
\>", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(liealgebra = \((algebra - Transpose[algebra])\)/2; 
    mtx[liealgebra]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and this closed 10-dimensional Lie algebra, isomorphic to \
so(3,2), can be the established \"algebra\".*) \
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "(*Some remarks are necessary here:\n\nThe Lie algebras are among those \
that do not include an \"identity\" element. However, \"identity\" serves as \
an essential placeholder in many AVF calculations, so the fundamental list \
\"elements\" ",
  StyleBox["must always",
    FontVariations->{"Underline"->True}],
  "  include an initial member to ",
  StyleBox["act",
    FontVariations->{"Underline"->True}],
  " as the \"identity\" element. If the algebra does not include an \
\"identity\", it must be supplied as the first member of \"elements\", and to \
preserve its \"unital\" action, the top row and left column of \"algebra\" \
must equal \"elements\" (or a truncated portion thereof).\n\nSince this is \
essential for correct operation of the program, the \"makealgebra[]\" command \
will always modify any multiplication table (supplied as its argument) so \
that this requirement is met; i.e., the top row and left column will be \
changed to \"elements\" before being assigned to \"algebra\". If the algebra \
includes the \"identity\" in the first member of \"elements\", this actually \
leaves it unchanged. If there is no identity element, a symbol for it may be \
entered as the second (optional) argument of \"makealgebra\" to become a new \
element in the first position of \"elements\". The multiplication table \
entered in the mandatory first argument will appear unchanged, except for \
having the new \"elements\" list prepended as the first row and column of \
\"algebra\". Products with the spurious \"identity\" will not conform to the \
algebra, but products of all other elements (which do belong to the algebra) \
will be unchanged. The new row and column can be considered just as \
convenient headers for the others.*)"
}], "Input",
  FontFamily->"Times"],

Cell["(*For example,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makealgebra[liealgebra, e]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["(*and the full list of elements is still retained,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Basic AVF multiplication, ** , now gives the non-associative Lie product \
for all Lie-algebra-valued forms, which in standard notation is written as a \
bracket. The CAV defined 1-form, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " , becomes a Lie-algebra-valued gauge potential,*) "
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Omega]\&^\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*where the expansion of the Lie bracket [",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " ,",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Omega]\&^\)\)\)]],
  "] is given directly by,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[\[Omega]\&^ ** \[Omega]\&^]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*All the Jacobi identities of the structure constants of this Lie algebra \
are involved in the triple self-product of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " , regardless of parentheses;*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((\[Omega]\&^ ** \[Omega]\&^)\) ** \[Omega]\&^ == \[Omega]\&^ ** \((\
\[Omega]\&^ ** \[Omega]\&^)\) == \[Omega]\&^ ** \[Omega]\&^ ** \[Omega]\&^ == 
      0\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The AVF form of the Yang-Mills equation includes the grades(0,1,2) \
curvature fields, F, for the gauge potential, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " ,*)"
}], "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(F = collect[d[\[Omega]\&^] + \[Omega]\&^ ** \[Omega]\&^/2]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*In the Clifford algebra, the curvature identity is expressed \
by,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[F] + \[Omega]\&^ ** \((F/2)\) - \((F/2)\) ** \[Omega]\&^\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*but in the Lie algebra, AVF 1-forms and 2-forms anti-commute and the \
Jacobi identities annul the triple ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " product, so the curvature identity simplifies to,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[F] + \[Omega]\&^ ** F == d[F] - F ** \[Omega]\&^ == 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*THE\ NON - ASSOCIATIVE\ OCTONION\ ALGEBRA*) \)\)], "Input",
  PageBreakAbove->True],

Cell["(*Introduce a new \"elements\" list,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(octonionbasis = {e\_0, e\_1, e\_2, e\_3, e\_4, e\_5, e\_6, 
          e\_7};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeelements[octonionbasis]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*A particular representation, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(C\^+\)\(,\)\)\(\ \)\)\)]],
  "of the octonion multiplication table is:*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(octoniontable = {{e\_0, e\_1, e\_2, e\_3, e\_4, e\_5, e\_6, 
            e\_7}, {e\_1, \(-e\_0\), e\_4, e\_7, \(-e\_2\), 
            e\_6, \(-e\_5\), \(-e\_3\)}, {e\_2, \(-e\_4\), \(-e\_0\), e\_5, 
            e\_1, \(-e\_3\), 
            e\_7, \(-e\_6\)}, {e\_3, \(-e\_7\), \(-e\_5\), \(-e\_0\), e\_6, 
            e\_2, \(-e\_4\), e\_1}, {e\_4, 
            e\_2, \(-e\_1\), \(-e\_6\), \(-e\_0\), e\_7, 
            e\_3, \(-e\_5\)}, {e\_5, \(-e\_6\), 
            e\_3, \(-e\_2\), \(-e\_7\), \(-e\_0\), e\_1, e\_4}, {e\_6, 
            e\_5, \(-e\_7\), e\_4, \(-e\_3\), \(-e\_1\), \(-e\_0\), 
            e\_2}, {e\_7, e\_3, e\_6, \(-e\_1\), 
            e\_5, \(-e\_4\), \(-e\_2\), \(-e\_0\)}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makealgebra[octoniontable]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The function \"associators[n]\" searches the algebra table for \
non-associative triple products and prints the first \"n\" it finds. If fewer \
than \"n\" are present, it prints \"Done\" and the number actually found, but \
in that case it could take a long time to search a high-dimension \
algebra.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(associators[9]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "*The absence of the triple ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_1, e\_2, e\_4}\)]],
  " implies that this is an associative quaternion subalgebra; i.e.,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((e\_1 ** e\_2)\) ** e\_4 - e\_1 ** \((e\_2 ** e\_4)\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Since ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_1, e\_2, e\_3}\)]],
  " do not associate, the 0-forms {q1, q2 , q3} introduced at the start as \
quaternions, become truncated octonions by \[Sigma] \[Rule] e ,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(o1 = q1 /. \[Sigma] -> e\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(o2 = q2 /. \[Sigma] -> e\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(o3 = q3 /. \[Sigma] -> e\)], "Input",
  InitializationCell->True],

Cell["(*and O1 will be an octonion-valued 1-form,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(O1 = o1 /. X -> \[Omega]\)], "Input",
  InitializationCell->True],

Cell["(*when \"makeforms\" is used,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeforms[coeffs[O1]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A special property of octonions guarantees that any two octonion \
0-forms are associative; e.g.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((o1 ** o2)\) ** o1 - o1 ** \((o2 ** o1)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\((o1 ** o2)\) ** o2 - o1 ** \((o2 ** o2)\)\)], "Input",
  InitializationCell->True],

Cell["(For three independent octonions, associativity is lost,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[\((o1 ** o2)\) ** o3 - o1 ** \((o2 ** o3)\)]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*but the \"flexible\" property is demonstrated by the opposite \
signs of the next expression,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[\((o3 ** o2)\) ** o1 - o3 ** \((o2 ** o1)\)]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The above associative property does not hold in general for \
octonion-valued 1-forms, which are not even triply power associative,*)\
\>", \
"Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(\((O1 ** O1)\) ** O1 - O1 ** \((O1 ** O1)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(collect[\((O1 ** O1)\) ** o1 - O1 ** \((O1 ** o1)\)]\)], "Input",
  InitializationCell->True],

Cell["(*but with no exterior product involved,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((o1 ** O1)\) ** o1 - o1 ** \((O1 ** o1)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*THE\ EXCEPTIONAL\ JORDAN\ ALGEBRA*) \)\)], "Input",
  PageBreakAbove->True],

Cell[TextData[{
  "(*All the finite Jordan algebras with one exception can be obtained from \
the symmetric derived algebras using \[CirclePlus] with associative \
underlying algebras. As mentioned in ",
  ButtonBox["Okubo's book (p.81)",
    ButtonData:>"reference",
    ButtonStyle->"Hyperlink"],
  ", octonion-valued matrices provide a representation for the single 27-dim. \
exceptional Jordan algebra. For brevity, we shall use the truncated octonion \
triplet {o1,o2,o3}, their conjugates, and 3 additional diagonal elements, to \
write a reduced 15-dim. example,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(o1\&_ = \(-o1\) /. X\_0 -> \(-X\_0\); 
    o2\&_ = \(-o2\) /. Y\_0 -> \(-Y\_0\); 
    o3\&_ = \(-o3\) /. Z\_0 -> \(-Z\_0\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The matrix J1 then represents a truncated element of the \
exceptional Jordan algebra,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(J1 = {{\(a\_1\) e\_0, o1, o2}, {o1\&_, \(a\_2\) e\_0, o3}, {o2\&_, 
          o3\&_, \(a\_3\) e\_0}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[%]\)], "Input",
  InitializationCell->True],

Cell["(*An independent matrix of the same form is given by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(J2 = J1 /. {a -> b, X -> U, Y -> V, Z -> W}; mtx[J2]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the symmetrized Jordan product \[CirclePlus] can be modified \
for matrix arguments to, *)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(CirclePlus[arg1_, arg2_] := 
      arg1\[CircleTimes]\((arg2/2)\) + \((arg2/
              2)\)\[CircleTimes]arg1\)], "Input",
  InitializationCell->True],

Cell["(*For example,*)", "Input",
  PageBreakAbove->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(J3 = collect[J1\[CirclePlus]J1]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Using matrix multiplication, the Jordan identity as introduced for the \
derived algebra ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\^+\)\)]],
  " becomes,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((\((J1\[CircleTimes]J1)\)\[CirclePlus]J2)\)\[CirclePlus]J1 - 
      \((J1\[CircleTimes]J1)\)\[CirclePlus]\((J2\[CirclePlus]J1)\)\)], "Input"],

Cell["\<\
(*or equivalently, using J3 = J1\[CirclePlus]J1, just calculated,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(reset[]; 
    \((J3\[CirclePlus]J2)\)\[CirclePlus]J1 - 
      J3\[CirclePlus]\((J2\[CirclePlus]J1)\)\), 
    \(timer[]\)}], "Input"],

Cell["\<\
(*Those statements require an order-of-magnitude more time than the \
rest of this entire program, and so were not initialized. Either can be \
executed now by selecting the cell and pressing enter.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*Executing the next statement confirms that the unsymmetrized \
matrix product is not associative.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[
      \((J3\[CircleTimes]J2)\)\[CircleTimes]J1 - 
        J3\[CircleTimes]\((J2\[CircleTimes]J1)\)]\)], "Input"],

Cell[BoxData[
    \(timer[]\)], "Input",
  InitializationCell->True],

Cell["\<\
Ref: \"Introduction to Octonion and Other Non-Associative Algebras \
in Physics\", S. Okubo, Montroll Memorial Lecture Series in Mathematical \
Physics: 2, Cambridge University Press, 1995\
\>", "Input",
  FontFamily->"Times",
  CellTags->"reference"]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
WindowSize->{636, 496},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:002
0000I00000400`<300000BL?00400@gZlT0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "reference"->{
    Cell[29553, 1004, 261, 6, 44, "Input",
      CellTags->"reference"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"reference", 31227, 1049}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 404, 12, 43, "Input"],
Cell[2161, 65, 654, 13, 92, "Input"],
Cell[2818, 80, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[2895, 84, 81, 1, 28, "Input"],
Cell[2979, 87, 129, 3, 27, "Input",
  InitializationCell->True],
Cell[3111, 92, 322, 5, 43, "Input",
  InitializationCell->True],
Cell[3436, 99, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[3514, 103, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[3583, 107, 79, 1, 28, "Input"],
Cell[3665, 110, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[3770, 114, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[3851, 118, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[3932, 122, 85, 1, 43, "Input"],
Cell[4020, 125, 164, 4, 28, "Input"],
Cell[4187, 131, 358, 7, 43, "Input",
  InitializationCell->True],
Cell[4548, 140, 212, 5, 44, "Input"],
Cell[4763, 147, 304, 5, 27, "Input",
  InitializationCell->True],
Cell[5070, 154, 374, 10, 44, "Input"],
Cell[5447, 166, 198, 3, 27, "Input",
  InitializationCell->True],
Cell[5648, 171, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[5722, 175, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[5836, 179, 110, 4, 44, "Input"],
Cell[5949, 185, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[6054, 189, 129, 4, 28, "Input"],
Cell[6186, 195, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[6276, 199, 353, 7, 60, "Input"],
Cell[6632, 208, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[6720, 212, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[6791, 216, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[6861, 220, 49, 1, 28, "Input"],
Cell[6913, 223, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[6982, 227, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[7069, 231, 130, 4, 28, "Input"],
Cell[7202, 237, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[7281, 241, 188, 5, 44, "Input"],
Cell[7472, 248, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[7544, 252, 123, 4, 28, "Input"],
Cell[7670, 258, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[7742, 262, 136, 4, 28, "Input"],
Cell[7881, 268, 226, 5, 51, "Input",
  InitializationCell->True],
Cell[8110, 275, 163, 4, 44, "Input"],
Cell[8276, 281, 231, 5, 51, "Input",
  InitializationCell->True],
Cell[8510, 288, 62, 1, 43, "Input"],
Cell[8575, 291, 667, 13, 95, "Input"],
Cell[9245, 306, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[9331, 310, 157, 4, 28, "Input"],
Cell[9491, 316, 716, 23, 34, "Input"],
Cell[10210, 341, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[10278, 345, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[10346, 349, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[10415, 353, 140, 4, 28, "Input"],
Cell[10558, 359, 146, 4, 27, "Input",
  InitializationCell->True],
Cell[10707, 365, 150, 4, 27, "Input",
  InitializationCell->True],
Cell[10860, 371, 85, 1, 28, "Input"],
Cell[10948, 374, 169, 3, 27, "Input",
  InitializationCell->True],
Cell[11120, 379, 103, 2, 28, "Input",
  PageBreakAbove->True],
Cell[11226, 383, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[11307, 387, 221, 5, 44, "Input"],
Cell[11531, 394, 272, 5, 59, "Input",
  InitializationCell->True],
Cell[11806, 401, 50, 1, 28, "Input"],
Cell[11859, 404, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[11935, 408, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[12008, 412, 87, 1, 28, "Input"],
Cell[12098, 415, 91, 2, 27, "Input",
  InitializationCell->True],
Cell[12192, 419, 156, 4, 28, "Input"],
Cell[12351, 425, 94, 2, 27, "Input",
  InitializationCell->True],
Cell[12448, 429, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[12517, 433, 302, 7, 60, "Input"],
Cell[12822, 442, 62, 1, 43, "Input"],
Cell[12887, 445, 443, 14, 44, "Input"],
Cell[13333, 461, 111, 4, 28, "Input"],
Cell[13447, 467, 140, 3, 27, "Input",
  InitializationCell->True],
Cell[13590, 472, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[13678, 476, 116, 4, 28, "Input"],
Cell[13797, 482, 139, 3, 27, "Input",
  InitializationCell->True],
Cell[13939, 487, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[14026, 491, 284, 8, 60, "Input",
  PageBreakAbove->True],
Cell[14313, 501, 219, 4, 27, "Input",
  InitializationCell->True],
Cell[14535, 507, 217, 6, 28, "Input"],
Cell[14755, 515, 206, 4, 27, "Input",
  InitializationCell->True],
Cell[14964, 521, 181, 5, 44, "Input"],
Cell[15148, 528, 224, 4, 27, "Input",
  InitializationCell->True],
Cell[15375, 534, 115, 4, 28, "Input"],
Cell[15493, 540, 216, 4, 27, "Input",
  InitializationCell->True],
Cell[15712, 546, 149, 4, 28, "Input"],
Cell[15864, 552, 96, 2, 43, "Input",
  PageBreakAbove->True],
Cell[15963, 556, 186, 5, 44, "Input"],
Cell[16152, 563, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[16250, 567, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[16322, 571, 206, 5, 44, "Input"],
Cell[16531, 578, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[16600, 582, 154, 5, 28, "Input",
  PageBreakAbove->True],
Cell[16757, 589, 132, 3, 43, "Input",
  InitializationCell->True],
Cell[16892, 594, 157, 4, 28, "Input"],
Cell[17052, 600, 1806, 29, 300, "Input"],
Cell[18861, 631, 56, 1, 28, "Input"],
Cell[18920, 634, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[19010, 638, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[19079, 642, 92, 1, 28, "Input"],
Cell[19174, 645, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[19246, 649, 360, 8, 60, "Input"],
Cell[19609, 659, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[19684, 663, 267, 9, 28, "Input"],
Cell[19954, 674, 96, 2, 27, "Input",
  InitializationCell->True],
Cell[20053, 678, 271, 7, 44, "Input"],
Cell[20327, 687, 218, 4, 27, "Input",
  InitializationCell->True],
Cell[20548, 693, 265, 8, 44, "Input",
  PageBreakAbove->True],
Cell[20816, 703, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[20938, 707, 118, 4, 28, "Input"],
Cell[21059, 713, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[21181, 717, 280, 7, 44, "Input"],
Cell[21464, 726, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[21583, 730, 110, 2, 43, "Input",
  PageBreakAbove->True],
Cell[21696, 734, 78, 1, 28, "Input"],
Cell[21777, 737, 141, 3, 27, "Input",
  InitializationCell->True],
Cell[21921, 742, 88, 2, 27, "Input",
  InitializationCell->True],
Cell[22012, 746, 209, 6, 28, "Input"],
Cell[22224, 754, 765, 13, 139, "Input",
  InitializationCell->True],
Cell[22992, 769, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[23082, 773, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[23151, 777, 353, 7, 60, "Input"],
Cell[23507, 786, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[23585, 790, 221, 6, 28, "Input"],
Cell[23809, 798, 116, 2, 27, "Input",
  InitializationCell->True],
Cell[23928, 802, 274, 7, 44, "Input"],
Cell[24205, 811, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[24293, 815, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[24381, 819, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[24469, 823, 85, 1, 28, "Input"],
Cell[24557, 826, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[24645, 830, 71, 1, 28, "Input"],
Cell[24719, 833, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[24804, 837, 149, 4, 28, "Input"],
Cell[24956, 843, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[25063, 847, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[25170, 851, 98, 1, 28, "Input"],
Cell[25271, 854, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[25387, 858, 145, 4, 28, "Input"],
Cell[25535, 864, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[25651, 868, 209, 6, 44, "Input",
  PageBreakAbove->True],
Cell[25863, 876, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[25970, 880, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[26086, 884, 82, 1, 28, "Input"],
Cell[26171, 887, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[26278, 891, 102, 2, 43, "Input",
  PageBreakAbove->True],
Cell[26383, 895, 608, 12, 92, "Input"],
Cell[26994, 909, 183, 4, 29, "Input",
  InitializationCell->True],
Cell[27180, 915, 138, 4, 28, "Input"],
Cell[27321, 921, 161, 3, 31, "Input",
  InitializationCell->True],
Cell[27485, 926, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[27555, 930, 95, 1, 28, "Input"],
Cell[27653, 933, 113, 2, 27, "Input",
  InitializationCell->True],
Cell[27769, 937, 144, 4, 28, "Input"],
Cell[27916, 943, 174, 4, 27, "Input",
  InitializationCell->True],
Cell[28093, 949, 80, 2, 28, "Input",
  PageBreakAbove->True],
Cell[28176, 953, 92, 2, 27, "Input",
  InitializationCell->True],
Cell[28271, 957, 219, 7, 28, "Input"],
Cell[28493, 966, 163, 2, 27, "Input"],
Cell[28659, 970, 117, 4, 28, "Input"],
Cell[28779, 976, 153, 4, 43, "Input"],
Cell[28935, 982, 248, 5, 44, "Input"],
Cell[29186, 989, 149, 4, 28, "Input"],
Cell[29338, 995, 141, 3, 27, "Input"],
Cell[29482, 1000, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[29553, 1004, 261, 6, 44, "Input",
  CellTags->"reference"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

